Learn R Programming

GPGame (version 1.2.1)

generate_integ_pts: Strategy generation

Description

Preprocessing to link strategies and designs.

Usage

generate_integ_pts(
  n.s,
  d,
  nobj,
  x.to.obj = NULL,
  gridtype = "cartesian",
  equilibrium = "NE",
  lb = rep(0, d),
  ub = rep(1, d),
  include.obs = FALSE,
  model = NULL,
  init_set = NULL,
  include_set = NULL,
  seed = 42
)

Value

A list containing two matrices, integ.pts the design of experiments and expanded.indices

the corresponding indices (for NE), and the vector n.s

Arguments

n.s

scalar or vector. If scalar, total number of strategies (to be divided equally among players), otherwise number of strategies per player.

d

number of variables

nobj

number of objectives (or players)

x.to.obj

vector allocating variables to objectives. If not provided, default is 1:nobj, assuming that d=nobj

gridtype

either "cartesian" or "lhs", or a vector to define a different type for each player.

equilibrium

either "NE", "KSE", "CKSE" or "NKSE"

lb, ub

vectors specifying the bounds of the design space, by default [0,1]^d

include.obs

Boolean, if TRUE observations given in model@X are added to the integration points (only for KSE and CKSE)

model

optional list of km models (used if include.obs=TRUE)

init_set

large grid to subsample from

include_set

grid to be included in the larger one generated

seed

random seed used by lhsDesign

Examples

Run this code
# \donttest{
##############################################
### 4 variables, 2 players, no filter
##############################################

# Create a 11x8 lattice based on 2 LHS designs
n.s <- c(11,8)
gridtype = "lhs"
# 4D space is split in 2
x.to.obj <- c(1,1,2,2)
integcontrol <- generate_integ_pts(n.s=n.s, d=4, nobj=2, x.to.obj = x.to.obj, gridtype=gridtype)
pairs(integcontrol$integ.pts)

# Create a simple 11x11 grid
integcontrol <- generate_integ_pts(n.s=11^2, d=2, nobj=2, gridtype="cartesian")
pairs(integcontrol$integ.pts)
# }

Run the code above in your browser using DataLab