Wrapper around solve_game to add iterations to an existing run
restart_sg(
results,
fun,
...,
equilibrium = "NE",
crit = "sur",
n.ite,
x.to.obj = NULL,
noise.var = NULL,
Nadir = NULL,
Shadow = NULL,
integcontrol = NULL,
simucontrol = NULL,
filtercontrol = NULL,
kmcontrol = NULL,
returncontrol = NULL,
ncores = 1,
trace = 1,
seed = NULL
)See solve_game.
output of solve_game that is to be continued
fonction with vectorial output
additional parameter to be passed to fun
either 'NE', 'KSE', 'CKSE' or 'NKSE' for Nash / Kalai-Smorodinsky / Copula-Kalai-Smorodinsky / Nash-Kalai-Smorodinsky equilibria
'sur' (default) is available for all equilibria, 'psim' and 'pex' are available for Nash
number of additional iterations of sequential optimization
for NE and NKSE, which variables for which objective
noise variance. Either a scalar (same noise for all objectives), a vector (constant noise, different for each objective), a function (type closure) with vectorial output (variable noise, different for each objective) or "given_by_fn", see Details. If not provided, noise.var is taken as the average of model@noise.var.
optional vectors of size nobj. Replaces the nadir or shadow point for KSE. If only a subset of values needs to be defined, the other coordinates can be set to Inf (resp. -Inf for the shadow).
optional list for handling integration points. See Details.
see solve_game
number of CPU available (> 1 makes mean parallel TRUE)
controls the level of printing: 0 (no printing), 1 (minimal printing), 3 (detailed printing)
to fix the random variable generator
Unless given new values, restart_sg reuses values stored in results (e.g., integcontrol).